@@ -2,6 +2,7 @@
  * guile-util.c -- utility functions for using guile for GnuCash    *
  * Copyright (C) 1999 Linas Vepstas                                 *
  * Copyright (C) 2000 Dave Peticolas                                *
+ * Copyright (C) 2017 Aaron Laws                                    *
  *                                                                  *
  * This program is free software; you can redistribute it and/or    *
  * modify it under the terms of the GNU General Public License as   *
@@ -520,7 +521,7 @@ gnc_split_scm_get_amount(SCM split_scm)
         return gnc_numeric_zero ();
 
     result = scm_call_1(getters.split_scm_amount, split_scm);
-    if (!gnc_numeric_p(result))
+    if (!scm_rational_p(result))
         return gnc_numeric_zero ();
 
     return gnc_scm_to_numeric(result);
@@ -545,7 +546,7 @@ gnc_split_scm_get_value(SCM split_scm)
         return gnc_numeric_zero ();
 
     result = scm_call_1(getters.split_scm_value, split_scm);
-    if (!gnc_numeric_p(result))
+    if (!scm_rational_p(result))
         return gnc_numeric_zero ();
 
     return gnc_scm_to_numeric(result);
@@ -707,19 +708,14 @@ gnc_copy_trans_scm_onto_trans_swap_accounts(SCM trans_scm,
  * Returns: Nothing                                                 *
 \********************************************************************/
 void
-gnc_trans_scm_set_date(SCM trans_scm, Timespec *ts)
+gnc_trans_scm_set_date(SCM trans_scm, time64 time)
 {
     SCM arg;
-
+    Timespec ts = {time, 0};
     initialize_scm_functions();
-
     if (!gnc_is_trans_scm(trans_scm))
         return;
-    if (ts == NULL)
-        return;
-
-    arg = gnc_timespec2timepair(*ts);
-
+    arg = gnc_timespec2timepair(ts);
     scm_call_2(setters.trans_scm_date, trans_scm, arg);
 }
 
