@@ -128,10 +128,7 @@ gnc_employee_get_property (GObject         *object,
                            GParamSpec      *pspec)
 {
     GncEmployee *emp;
-    gchar *key;
-
     g_return_if_fail(GNC_IS_EMPLOYEE(object));
-
     emp = GNC_EMPLOYEE(object);
     switch (prop_id)
     {
@@ -166,17 +163,14 @@ gnc_employee_get_property (GObject         *object,
         g_value_take_object(value, emp->ccard_acc);
         break;
     case PROP_PDF_DIRNAME:
-	key = OWNER_EXPORT_PDF_DIRNAME;
-	qof_instance_get_kvp (QOF_INSTANCE (emp), key, value);
-	break;
+        qof_instance_get_kvp (QOF_INSTANCE (emp), value, 1, OWNER_EXPORT_PDF_DIRNAME);
+        break;
     case PROP_LAST_POSTED:
-	key = LAST_POSTED_TO_ACCT;
-	qof_instance_get_kvp (QOF_INSTANCE (emp), key, value);
-	break;
+        qof_instance_get_kvp (QOF_INSTANCE (emp), value, 1, LAST_POSTED_TO_ACCT);
+        break;
     case PROP_PAYMENT_LAST_ACCT:
-	key = GNC_PAYMENT "/" GNC_LAST_ACCOUNT;
-	qof_instance_get_kvp (QOF_INSTANCE (emp), key, value);
-	break;
+        qof_instance_get_kvp (QOF_INSTANCE (emp), value, 2, GNC_PAYMENT, GNC_LAST_ACCOUNT);
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
         break;
@@ -190,13 +184,9 @@ gnc_employee_set_property (GObject         *object,
                            GParamSpec      *pspec)
 {
     GncEmployee *emp;
-    gchar *key;
-
     g_return_if_fail(GNC_IS_EMPLOYEE(object));
-
     emp = GNC_EMPLOYEE(object);
     g_assert (qof_instance_get_editlevel(emp));
-
     switch (prop_id)
     {
     case PROP_USERNAME:
@@ -230,17 +220,14 @@ gnc_employee_set_property (GObject         *object,
         gncEmployeeSetCCard(emp, g_value_get_object(value));
         break;
     case PROP_PDF_DIRNAME:
-	key = OWNER_EXPORT_PDF_DIRNAME;
-	qof_instance_set_kvp (QOF_INSTANCE (emp), key, value);
-	break;
+        qof_instance_set_kvp (QOF_INSTANCE (emp), value, 1, OWNER_EXPORT_PDF_DIRNAME);
+        break;
     case PROP_LAST_POSTED:
-	key = LAST_POSTED_TO_ACCT;
-	qof_instance_set_kvp (QOF_INSTANCE (emp), key, value);
-	break;
+        qof_instance_set_kvp (QOF_INSTANCE (emp), value, 1, LAST_POSTED_TO_ACCT);
+        break;
     case PROP_PAYMENT_LAST_ACCT:
-	key = GNC_PAYMENT "/" GNC_LAST_ACCOUNT;
-	qof_instance_set_kvp (QOF_INSTANCE (emp), key, value);
-	break;
+        qof_instance_set_kvp (QOF_INSTANCE (emp), value, 2, GNC_PAYMENT, GNC_LAST_ACCOUNT);
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
         break;
